=== modified file 'mandos-ctl'
--- mandos-ctl	2019-03-09 16:14:06 +0000
+++ mandos-ctl	2019-03-06 18:33:51 +0000
@@ -42,9 +42,6 @@
 import json
 import unittest
 import logging
-import io
-import tempfile
-import contextlib
 
 import dbus
 
@@ -276,7 +273,7 @@
 # Abstract classes first
 class Command(object):
     """Abstract class for commands"""
-    def run(self, mandos, mandos_objmgr, clients):
+    def run(self, mandos, clients):
         """Normal commands should implement run_on_one_client(), but
         commands which want to operate on all clients at the same time
         can override this run() method instead."""
@@ -293,19 +290,13 @@
                     "LastApprovalRequest", "ApprovalDelay",
                     "ApprovalDuration", "Checker", "ExtendedTimeout",
                     "Expires", "LastCheckerStatus")
-    def run(self, mandos, mandos_objmgr, clients):
-        print(self.output(mandos_objmgr, clients.values()))
+    def run(self, mandos, clients):
+        print(self.output(clients))
 
 class PropertyCmd(Command):
     """Abstract class for Actions for setting one client property"""
     def run_on_one_client(self, client, properties):
         """Set the Client's D-Bus property"""
-        log.debug("D-Bus: %s:%s:%s.Set(%r, %r, %r)", busname,
-                  client.__dbus_object_path__,
-                  dbus.PROPERTIES_IFACE, client_interface,
-                  self.property, self.value_to_set
-                  if not isinstance(self.value_to_set, dbus.Boolean)
-                  else bool(self.value_to_set))
         client.Set(client_interface, self.property, self.value_to_set,
                    dbus_interface=dbus.PROPERTIES_IFACE)
 
@@ -323,7 +314,7 @@
     @value_to_set.setter
     def value_to_set(self, value):
         """When setting, convert value to a datetime.timedelta"""
-        self._vts = int(round(value.total_seconds() * 1000))
+        self._vts = string_to_delta(value).total_seconds() * 1000
 
 # Actual (non-abstract) command classes
 
@@ -331,12 +322,12 @@
     def __init__(self, verbose=False):
         self.verbose = verbose
 
-    def output(self, mandos_objmgr, clients):
+    def output(self, clients):
         default_keywords = ("Name", "Enabled", "Timeout", "LastCheckedOK")
         keywords = default_keywords
         if self.verbose:
             keywords = self.all_keywords
-        return str(self.TableOfClients(clients, keywords))
+        return str(self.TableOfClients(clients.values(), keywords))
 
     class TableOfClients(object):
         tableheaders = {
@@ -415,7 +406,7 @@
 
 
 class DumpJSONCmd(PrintCmd):
-    def output(self, mandos_objmgr, clients):
+    def output(self, clients):
         data = {client["Name"]:
                 {key: self.dbus_boolean_to_bool(client[key])
                  for key in self.all_keywords}
@@ -433,31 +424,19 @@
             sys.exit(0)
         sys.exit(1)
     def is_enabled(self, client, properties):
-        log.debug("D-Bus: %s:%s:%s.Get(%r, %r)", busname,
-                  client.__dbus_object_path__,
-                  dbus.PROPERTIES_IFACE, client_interface,
-                  "Enabled")
-        return bool(client.Get(client_interface, "Enabled",
-                               dbus_interface=dbus.PROPERTIES_IFACE))
+        return bool(properties["Enabled"])
 
 class RemoveCmd(Command):
     def run_on_one_client(self, client, properties):
-        log.debug("D-Bus: %s:%s:%s.RemoveClient(%r)", busname,
-                  server_path, server_interface,
-                  str(client.__dbus_object_path__))
         self.mandos.RemoveClient(client.__dbus_object_path__)
 
 class ApproveCmd(Command):
     def run_on_one_client(self, client, properties):
-        log.debug("D-Bus: %s:%s.Approve(True)",
-                  client.__dbus_object_path__, client_interface)
         client.Approve(dbus.Boolean(True),
                        dbus_interface=client_interface)
 
 class DenyCmd(Command):
     def run_on_one_client(self, client, properties):
-        log.debug("D-Bus: %s:%s.Approve(False)",
-                  client.__dbus_object_path__, client_interface)
         client.Approve(dbus.Boolean(False),
                        dbus_interface=client_interface)
 
@@ -496,14 +475,6 @@
     property = "Host"
 
 class SetSecretCmd(PropertyCmd, ValueArgumentMixIn):
-    @property
-    def value_to_set(self):
-        return self._vts
-    @value_to_set.setter
-    def value_to_set(self, value):
-        """When setting, read data from supplied file object"""
-        self._vts = value.read()
-        value.close()
     property = "Secret"
 
 class SetTimeoutCmd(PropertyCmd, MillisecondsValueArgumentMixIn):
@@ -524,6 +495,26 @@
                              MillisecondsValueArgumentMixIn):
     property = "ApprovalDuration"
 
+def has_actions(options):
+    return any((options.enable,
+                options.disable,
+                options.bump_timeout,
+                options.start_checker,
+                options.stop_checker,
+                options.is_enabled,
+                options.remove,
+                options.checker is not None,
+                options.timeout is not None,
+                options.extended_timeout is not None,
+                options.interval is not None,
+                options.approved_by_default is not None,
+                options.approval_delay is not None,
+                options.approval_duration is not None,
+                options.host is not None,
+                options.secret is not None,
+                options.approve,
+                options.deny))
+
 def add_command_line_options(parser):
     parser.add_argument("--version", action="version",
                         version="%(prog)s {}".format(version),
@@ -555,11 +546,11 @@
                         help="Remove client")
     parser.add_argument("-c", "--checker",
                         help="Set checker command for client")
-    parser.add_argument("-t", "--timeout", type=string_to_delta,
+    parser.add_argument("-t", "--timeout",
                         help="Set timeout for client")
-    parser.add_argument("--extended-timeout", type=string_to_delta,
+    parser.add_argument("--extended-timeout",
                         help="Set extended timeout for client")
-    parser.add_argument("-i", "--interval", type=string_to_delta,
+    parser.add_argument("-i", "--interval",
                         help="Set checker interval for client")
     approve_deny_default = parser.add_mutually_exclusive_group()
     approve_deny_default.add_argument(
@@ -570,9 +561,9 @@
         "--deny-by-default", action="store_false",
         dest="approved_by_default",
         help="Set client to be denied by default")
-    parser.add_argument("--approval-delay", type=string_to_delta,
+    parser.add_argument("--approval-delay",
                         help="Set delay before client approve/deny")
-    parser.add_argument("--approval-duration", type=string_to_delta,
+    parser.add_argument("--approval-duration",
                         help="Set duration of one client approval")
     parser.add_argument("-H", "--host", help="Set host for client")
     parser.add_argument("-s", "--secret",
@@ -584,8 +575,6 @@
         help="Approve any current client request")
     approve_deny.add_argument("-D", "--deny", action="store_true",
                               help="Deny any current client request")
-    parser.add_argument("--debug", action="store_true",
-                        help="Debug mode (show D-Bus commands)")
     parser.add_argument("--check", action="store_true",
                         help="Run self-test")
     parser.add_argument("client", nargs="*", help="Client name")
@@ -616,8 +605,11 @@
     if options.is_enabled:
         commands.append(IsEnabledCmd())
 
+    if options.remove:
+        commands.append(RemoveCmd())
+
     if options.checker is not None:
-        commands.append(SetCheckerCmd(options.checker))
+        commands.append(SetCheckerCmd())
 
     if options.timeout is not None:
         commands.append(SetTimeoutCmd(options.timeout))
@@ -627,26 +619,26 @@
             SetExtendedTimeoutCmd(options.extended_timeout))
 
     if options.interval is not None:
-        commands.append(SetIntervalCmd(options.interval))
+        command.append(SetIntervalCmd(options.interval))
 
     if options.approved_by_default is not None:
         if options.approved_by_default:
-            commands.append(ApproveByDefaultCmd())
+            command.append(ApproveByDefaultCmd())
         else:
-            commands.append(DenyByDefaultCmd())
+            command.append(DenyByDefaultCmd())
 
     if options.approval_delay is not None:
-        commands.append(SetApprovalDelayCmd(options.approval_delay))
+        command.append(SetApprovalDelayCmd(options.approval_delay))
 
     if options.approval_duration is not None:
-        commands.append(
+        command.append(
             SetApprovalDurationCmd(options.approval_duration))
 
     if options.host is not None:
-        commands.append(SetHostCmd(options.host))
+        command.append(SetHostCmd(options.host))
 
     if options.secret is not None:
-        commands.append(SetSecretCmd(options.secret))
+        command.append(SetSecretCmd(options.secret))
 
     if options.approve:
         commands.append(ApproveCmd())
@@ -654,9 +646,6 @@
     if options.deny:
         commands.append(DenyCmd())
 
-    if options.remove:
-        commands.append(RemoveCmd())
-
     # If no command option has been given, show table of clients,
     # optionally verbosely
     if not commands:
@@ -665,29 +654,12 @@
     return commands
 
 
-def check_option_syntax(parser, options):
-    """Apply additional restrictions on options, not expressible in
-argparse"""
-
-    def has_actions(options):
-        return any((options.enable,
-                    options.disable,
-                    options.bump_timeout,
-                    options.start_checker,
-                    options.stop_checker,
-                    options.is_enabled,
-                    options.remove,
-                    options.checker is not None,
-                    options.timeout is not None,
-                    options.extended_timeout is not None,
-                    options.interval is not None,
-                    options.approved_by_default is not None,
-                    options.approval_delay is not None,
-                    options.approval_duration is not None,
-                    options.host is not None,
-                    options.secret is not None,
-                    options.approve,
-                    options.deny))
+def main():
+    parser = argparse.ArgumentParser()
+
+    add_command_line_options(parser)
+
+    options = parser.parse_args()
 
     if has_actions(options) and not (options.client or options.all):
         parser.error("Options require clients names or --all.")
@@ -700,31 +672,11 @@
         parser.error("--all requires an action.")
     if options.is_enabled and len(options.client) > 1:
         parser.error("--is-enabled requires exactly one client")
-    if options.remove:
-        options.remove = False
-        if has_actions(options) and not options.deny:
-            parser.error("--remove can only be combined with --deny")
-        options.remove = True
-
-
-def main():
-    parser = argparse.ArgumentParser()
-
-    add_command_line_options(parser)
-
-    options = parser.parse_args()
-
-    check_option_syntax(parser, options)
 
     clientnames = options.client
 
-    if options.debug:
-        log.setLevel(logging.DEBUG)
-
     try:
         bus = dbus.SystemBus()
-        log.debug("D-Bus: Connect to: (name=%r, path=%r)", busname,
-                  server_path)
         mandos_dbus_objc = bus.get_object(busname, server_path)
     except dbus.exceptions.DBusException:
         log.critical("Could not connect to Mandos server")
@@ -743,8 +695,6 @@
     dbus_filter = NullFilter()
     try:
         dbus_logger.addFilter(dbus_filter)
-        log.debug("D-Bus: %s:%s:%s.GetManagedObjects()", busname,
-                  server_path, dbus.OBJECT_MANAGER_IFACE)
         mandos_clients = {path: ifs_and_props[client_interface]
                           for path, ifs_and_props in
                           mandos_serv_object_manager
@@ -762,16 +712,12 @@
     clients = {}
 
     if not clientnames:
-        clients = {(log.debug("D-Bus: Connect to: (name=%r, path=%r)",
-                              busname, str(path)) and False) or
-                   bus.get_object(busname, path): properties
+        clients = {bus.get_object(busname, path): properties
                    for path, properties in mandos_clients.items()}
     else:
         for name in clientnames:
             for path, client in mandos_clients.items():
                 if client["Name"] == name:
-                    log.debug("D-Bus: Connect to: (name=%r, path=%r)",
-                              busname, str(path))
                     client_objc = bus.get_object(busname, path)
                     clients[client_objc] = client
                     break
@@ -782,7 +728,7 @@
     # Run all commands on clients
     commands = commands_from_options(options)
     for command in commands:
-        command.run(mandos_serv, mandos_serv_object_manager, clients)
+        command.run(mandos_serv, clients)
 
 
 class Test_milliseconds_to_string(unittest.TestCase):
@@ -912,7 +858,7 @@
 
 class TestPrintTableCmd(TestCmd):
     def test_normal(self):
-        output = PrintTableCmd().output(None, self.clients.values())
+        output = PrintTableCmd().output(self.clients)
         expected_output = """
 Name   Enabled Timeout  Last Successful Check
 foo    Yes     00:05:00 2019-02-03T00:00:00  
@@ -920,8 +866,7 @@
 """[1:-1]
         self.assertEqual(output, expected_output)
     def test_verbose(self):
-        output = PrintTableCmd(verbose=True).output(
-            None, self.clients.values())
+        output = PrintTableCmd(verbose=True).output(self.clients)
         expected_output = """
 Name   Enabled Timeout  Last Successful Check Created             Interval Host            Key ID                                                           Fingerprint                              Check Is Running Last Enabled        Approval Is Pending Approved By Default Last Approval Request Approval Delay Approval Duration Checker              Extended Timeout Expires             Last Checker Status
 foo    Yes     00:05:00 2019-02-03T00:00:00   2019-01-02T00:00:00 00:02:00 foo.example.org 92ed150794387c03ce684574b1139a6594a34f895daaaf09fd8ea90a27cddb12 778827225BA7DE539C5A7CFA59CFF7CDBD9A5920 No               2019-01-03T00:00:00 No                  Yes                                       00:00:00       00:00:01          fping -q -- %(host)s 00:15:00         2019-02-04T00:00:00 0                  
@@ -929,7 +874,7 @@
 """[1:-1]
         self.assertEqual(output, expected_output)
     def test_one_client(self):
-        output = PrintTableCmd().output(None, self.one_client.values())
+        output = PrintTableCmd().output(self.one_client)
         expected_output = """
 Name Enabled Timeout  Last Successful Check
 foo  Yes     00:05:00 2019-02-03T00:00:00  
@@ -990,12 +935,11 @@
         }
         return super(TestDumpJSONCmd, self).setUp()
     def test_normal(self):
-        json_data = json.loads(DumpJSONCmd().output(None,
-                                                    self.clients))
+        json_data = json.loads(DumpJSONCmd().output(self.clients))
         self.assertDictEqual(json_data, self.expected_json)
     def test_one_client(self):
         clients = self.one_client
-        json_data = json.loads(DumpJSONCmd().output(None, clients))
+        json_data = json.loads(DumpJSONCmd().output(clients))
         expected_json = {"foo": self.expected_json["foo"]}
         self.assertDictEqual(json_data, expected_json)
 
@@ -1005,7 +949,7 @@
                             for client, properties in self.clients.items()))
     def test_is_enabled_run_exits_successfully(self):
         with self.assertRaises(SystemExit) as e:
-            IsEnabledCmd().run(None, None, self.one_client)
+            IsEnabledCmd().run(None, self.one_client)
         if e.exception.code is not None:
             self.assertEqual(e.exception.code, 0)
         else:
@@ -1013,7 +957,7 @@
     def test_is_enabled_run_exits_with_failure(self):
         self.client.attributes["Enabled"] = dbus.Boolean(False)
         with self.assertRaises(SystemExit) as e:
-            IsEnabledCmd().run(None, None, self.one_client)
+            IsEnabledCmd().run(None, self.one_client)
         if isinstance(e.exception.code, int):
             self.assertNotEqual(e.exception.code, 0)
         else:
@@ -1028,7 +972,7 @@
                 self.calls.append(("RemoveClient", (dbus_path,)))
         mandos = MockMandos()
         super(TestRemoveCmd, self).setUp()
-        RemoveCmd().run(mandos, None, self.clients)
+        RemoveCmd().run(mandos, self.clients)
         self.assertEqual(len(mandos.calls), 2)
         for client in self.clients:
             self.assertIn(("RemoveClient",
@@ -1037,14 +981,14 @@
 
 class TestApproveCmd(TestCmd):
     def test_approve(self):
-        ApproveCmd().run(None, None, self.clients)
+        ApproveCmd().run(None, self.clients)
         for client in self.clients:
             self.assertIn(("Approve", (True, client_interface)),
                           client.calls)
 
 class TestDenyCmd(TestCmd):
     def test_deny(self):
-        DenyCmd().run(None, None, self.clients)
+        DenyCmd().run(None, self.clients)
         for client in self.clients:
             self.assertIn(("Approve", (False, client_interface)),
                           client.calls)
@@ -1054,14 +998,14 @@
         for client in self.clients:
             client.attributes["Enabled"] = False
 
-        EnableCmd().run(None, None, self.clients)
+        EnableCmd().run(None, self.clients)
 
         for client in self.clients:
             self.assertTrue(client.attributes["Enabled"])
 
 class TestDisableCmd(TestCmd):
     def test_disable(self):
-        DisableCmd().run(None, None, self.clients)
+        DisableCmd().run(None, self.clients)
 
         for client in self.clients:
             self.assertFalse(client.attributes["Enabled"])
@@ -1089,7 +1033,7 @@
                 self.assertNotIsInstance(value, Unique)
                 self.assertEqual(value, value_to_get)
     def run_command(self, value, clients):
-        self.command().run(None, None, clients)
+        self.command().run(None, clients)
 
 class TestBumpTimeoutCmd(TestPropertyCmd):
     command = BumpTimeoutCmd
@@ -1124,7 +1068,7 @@
             return
         return super(TestValueArgumentPropertyCmd, self).runTest()
     def run_command(self, value, clients):
-        self.command(value).run(None, None, clients)
+        self.command(value).run(None, clients)
 
 class TestSetCheckerCmd(TestValueArgumentPropertyCmd):
     command = SetCheckerCmd
@@ -1139,384 +1083,69 @@
 class TestSetSecretCmd(TestValueArgumentPropertyCmd):
     command = SetSecretCmd
     property = "Secret"
-    values_to_set = [io.BytesIO(b""),
-                     io.BytesIO(b"secret\0xyzzy\nbar")]
-    values_to_get = [b"", b"secret\0xyzzy\nbar"]
+    values_to_set = [b"", b"secret"]
 
 class TestSetTimeoutCmd(TestValueArgumentPropertyCmd):
     command = SetTimeoutCmd
     property = "Timeout"
-    values_to_set = [datetime.timedelta(),
-                     datetime.timedelta(minutes=5),
-                     datetime.timedelta(seconds=1),
-                     datetime.timedelta(weeks=1),
-                     datetime.timedelta(weeks=52)]
-    values_to_get = [0, 300000, 1000, 604800000, 31449600000]
+    values_to_set = ["P0D", "PT5M", "PT1S", "PT120S", "P1Y"]
+    values_to_get = [0, 300000, 1000, 120000, 31449600000]
 
 class TestSetExtendedTimeoutCmd(TestValueArgumentPropertyCmd):
     command = SetExtendedTimeoutCmd
     property = "ExtendedTimeout"
-    values_to_set = [datetime.timedelta(),
-                     datetime.timedelta(minutes=5),
-                     datetime.timedelta(seconds=1),
-                     datetime.timedelta(weeks=1),
-                     datetime.timedelta(weeks=52)]
-    values_to_get = [0, 300000, 1000, 604800000, 31449600000]
+    values_to_set = ["P0D", "PT5M", "PT1S", "PT120S", "P1Y"]
+    values_to_get = [0, 300000, 1000, 120000, 31449600000]
 
 class TestSetIntervalCmd(TestValueArgumentPropertyCmd):
     command = SetIntervalCmd
     property = "Interval"
-    values_to_set = [datetime.timedelta(),
-                     datetime.timedelta(minutes=5),
-                     datetime.timedelta(seconds=1),
-                     datetime.timedelta(weeks=1),
-                     datetime.timedelta(weeks=52)]
-    values_to_get = [0, 300000, 1000, 604800000, 31449600000]
+    values_to_set = ["P0D", "PT5M", "PT1S", "PT120S", "P1Y"]
+    values_to_get = [0, 300000, 1000, 120000, 31449600000]
 
 class TestSetApprovalDelayCmd(TestValueArgumentPropertyCmd):
     command = SetApprovalDelayCmd
     property = "ApprovalDelay"
-    values_to_set = [datetime.timedelta(),
-                     datetime.timedelta(minutes=5),
-                     datetime.timedelta(seconds=1),
-                     datetime.timedelta(weeks=1),
-                     datetime.timedelta(weeks=52)]
-    values_to_get = [0, 300000, 1000, 604800000, 31449600000]
+    values_to_set = ["P0D", "PT5M", "PT1S", "PT120S", "P1Y"]
+    values_to_get = [0, 300000, 1000, 120000, 31449600000]
 
 class TestSetApprovalDurationCmd(TestValueArgumentPropertyCmd):
     command = SetApprovalDurationCmd
     property = "ApprovalDuration"
-    values_to_set = [datetime.timedelta(),
-                     datetime.timedelta(minutes=5),
-                     datetime.timedelta(seconds=1),
-                     datetime.timedelta(weeks=1),
-                     datetime.timedelta(weeks=52)]
-    values_to_get = [0, 300000, 1000, 604800000, 31449600000]
+    values_to_set = ["P0D", "PT5M", "PT1S", "PT120S", "P1Y"]
+    values_to_get = [0, 300000, 1000, 120000, 31449600000]
 
-class Test_command_from_options(unittest.TestCase):
+class TestOptions(unittest.TestCase):
     def setUp(self):
         self.parser = argparse.ArgumentParser()
         add_command_line_options(self.parser)
-    def assert_command_from_args(self, args, command_cls, **cmd_attrs):
-        """Assert that parsing ARGS should result in an instance of
-COMMAND_CLS with (optionally) all supplied attributes (CMD_ATTRS)."""
-        options = self.parser.parse_args(args)
-        check_option_syntax(self.parser, options)
-        commands = commands_from_options(options)
-        self.assertEqual(len(commands), 1)
-        command = commands[0]
-        self.assertIsInstance(command, command_cls)
-        for key, value in cmd_attrs.items():
-            self.assertEqual(getattr(command, key), value)
-    def test_print_table(self):
-        self.assert_command_from_args([], PrintTableCmd,
-                                      verbose=False)
-
-    def test_print_table_verbose(self):
-        self.assert_command_from_args(["--verbose"], PrintTableCmd,
-                                      verbose=True)
-
-    def test_print_table_verbose_short(self):
-        self.assert_command_from_args(["-v"], PrintTableCmd,
-                                      verbose=True)
-
+    def commands_from_args(self, args):
+        self.options = self.parser.parse_args(args)
+        return commands_from_options(self.options)
+    def test_default_is_show_table(self):
+        commands = self.commands_from_args([])
+        self.assertEqual(len(commands), 1)
+        command = commands[0]
+        self.assertIsInstance(command, PrintTableCmd)
+        self.assertEqual(command.verbose, False)
+    def test_show_table_verbose(self):
+        commands = self.commands_from_args(["--verbose"])
+        self.assertEqual(len(commands), 1)
+        command = commands[0]
+        self.assertIsInstance(command, PrintTableCmd)
+        self.assertEqual(command.verbose, True)
     def test_enable(self):
-        self.assert_command_from_args(["--enable", "foo"], EnableCmd)
-
-    def test_enable_short(self):
-        self.assert_command_from_args(["-e", "foo"], EnableCmd)
-
+        commands = self.commands_from_args(["--enable", "foo"])
+        self.assertEqual(len(commands), 1)
+        command = commands[0]
+        self.assertIsInstance(command, EnableCmd)
+        self.assertEqual(self.options.client, ["foo"])
     def test_disable(self):
-        self.assert_command_from_args(["--disable", "foo"],
-                                      DisableCmd)
-
-    def test_disable_short(self):
-        self.assert_command_from_args(["-d", "foo"], DisableCmd)
-
-    def test_bump_timeout(self):
-        self.assert_command_from_args(["--bump-timeout", "foo"],
-                                      BumpTimeoutCmd)
-
-    def test_bump_timeout_short(self):
-        self.assert_command_from_args(["-b", "foo"], BumpTimeoutCmd)
-
-    def test_start_checker(self):
-        self.assert_command_from_args(["--start-checker", "foo"],
-                                      StartCheckerCmd)
-
-    def test_stop_checker(self):
-        self.assert_command_from_args(["--stop-checker", "foo"],
-                                      StopCheckerCmd)
-
-    def test_remove(self):
-        self.assert_command_from_args(["--remove", "foo"],
-                                      RemoveCmd)
-
-    def test_remove_short(self):
-        self.assert_command_from_args(["-r", "foo"], RemoveCmd)
-
-    def test_checker(self):
-        self.assert_command_from_args(["--checker", ":", "foo"],
-                                      SetCheckerCmd, value_to_set=":")
-
-    def test_checker_empty(self):
-        self.assert_command_from_args(["--checker", "", "foo"],
-                                      SetCheckerCmd, value_to_set="")
-
-    def test_checker_short(self):
-        self.assert_command_from_args(["-c", ":", "foo"],
-                                      SetCheckerCmd, value_to_set=":")
-
-    def test_timeout(self):
-        self.assert_command_from_args(["--timeout", "PT5M", "foo"],
-                                      SetTimeoutCmd,
-                                      value_to_set=300000)
-
-    def test_timeout_short(self):
-        self.assert_command_from_args(["-t", "PT5M", "foo"],
-                                      SetTimeoutCmd,
-                                      value_to_set=300000)
-
-    def test_extended_timeout(self):
-        self.assert_command_from_args(["--extended-timeout", "PT15M",
-                                       "foo"],
-                                      SetExtendedTimeoutCmd,
-                                      value_to_set=900000)
-
-    def test_interval(self):
-        self.assert_command_from_args(["--interval", "PT2M", "foo"],
-                                      SetIntervalCmd,
-                                      value_to_set=120000)
-
-    def test_interval_short(self):
-        self.assert_command_from_args(["-i", "PT2M", "foo"],
-                                      SetIntervalCmd,
-                                      value_to_set=120000)
-
-    def test_approve_by_default(self):
-        self.assert_command_from_args(["--approve-by-default", "foo"],
-                                      ApproveByDefaultCmd)
-
-    def test_deny_by_default(self):
-        self.assert_command_from_args(["--deny-by-default", "foo"],
-                                      DenyByDefaultCmd)
-
-    def test_approval_delay(self):
-        self.assert_command_from_args(["--approval-delay", "PT30S",
-                                       "foo"], SetApprovalDelayCmd,
-                                      value_to_set=30000)
-
-    def test_approval_duration(self):
-        self.assert_command_from_args(["--approval-duration", "PT1S",
-                                       "foo"], SetApprovalDurationCmd,
-                                      value_to_set=1000)
-
-    def test_host(self):
-        self.assert_command_from_args(["--host", "foo.example.org",
-                                       "foo"], SetHostCmd,
-                                      value_to_set="foo.example.org")
-
-    def test_host_short(self):
-        self.assert_command_from_args(["-H", "foo.example.org",
-                                       "foo"], SetHostCmd,
-                                      value_to_set="foo.example.org")
-
-    def test_secret_devnull(self):
-        self.assert_command_from_args(["--secret", os.path.devnull,
-                                       "foo"], SetSecretCmd,
-                                      value_to_set=b"")
-
-    def test_secret_tempfile(self):
-        with tempfile.NamedTemporaryFile(mode="r+b") as f:
-            value = b"secret\0xyzzy\nbar"
-            f.write(value)
-            f.seek(0)
-            self.assert_command_from_args(["--secret", f.name,
-                                           "foo"], SetSecretCmd,
-                                          value_to_set=value)
-
-    def test_secret_devnull_short(self):
-        self.assert_command_from_args(["-s", os.path.devnull, "foo"],
-                                      SetSecretCmd, value_to_set=b"")
-
-    def test_secret_tempfile_short(self):
-        with tempfile.NamedTemporaryFile(mode="r+b") as f:
-            value = b"secret\0xyzzy\nbar"
-            f.write(value)
-            f.seek(0)
-            self.assert_command_from_args(["-s", f.name, "foo"],
-                                          SetSecretCmd,
-                                          value_to_set=value)
-
-    def test_approve(self):
-        self.assert_command_from_args(["--approve", "foo"],
-                                      ApproveCmd)
-
-    def test_approve_short(self):
-        self.assert_command_from_args(["-A", "foo"], ApproveCmd)
-
-    def test_deny(self):
-        self.assert_command_from_args(["--deny", "foo"], DenyCmd)
-
-    def test_deny_short(self):
-        self.assert_command_from_args(["-D", "foo"], DenyCmd)
-
-    def test_dump_json(self):
-        self.assert_command_from_args(["--dump-json"], DumpJSONCmd)
-
-    def test_is_enabled(self):
-        self.assert_command_from_args(["--is-enabled", "foo"],
-                                      IsEnabledCmd)
-
-    def test_is_enabled_short(self):
-        self.assert_command_from_args(["-V", "foo"], IsEnabledCmd)
-
-    def test_deny_before_remove(self):
-        options = self.parser.parse_args(["--deny", "--remove", "foo"])
-        check_option_syntax(self.parser, options)
-        commands = commands_from_options(options)
-        self.assertEqual(len(commands), 2)
-        self.assertIsInstance(commands[0], DenyCmd)
-        self.assertIsInstance(commands[1], RemoveCmd)
-
-    def test_deny_before_remove_reversed(self):
-        options = self.parser.parse_args(["--remove", "--deny", "--all"])
-        check_option_syntax(self.parser, options)
-        commands = commands_from_options(options)
-        self.assertEqual(len(commands), 2)
-        self.assertIsInstance(commands[0], DenyCmd)
-        self.assertIsInstance(commands[1], RemoveCmd)
-
-
-class Test_check_option_syntax(unittest.TestCase):
-    # This mostly corresponds to the definition from has_actions() in
-    # check_option_syntax()
-    actions = {
-        # The actual values set here are not that important, but we do
-        # at least stick to the correct types, even though they are
-        # never used
-        "enable": True,
-        "disable": True,
-        "bump_timeout": True,
-        "start_checker": True,
-        "stop_checker": True,
-        "is_enabled": True,
-        "remove": True,
-        "checker": "x",
-        "timeout": datetime.timedelta(),
-        "extended_timeout": datetime.timedelta(),
-        "interval": datetime.timedelta(),
-        "approved_by_default": True,
-        "approval_delay": datetime.timedelta(),
-        "approval_duration": datetime.timedelta(),
-        "host": "x",
-        "secret": io.BytesIO(b"x"),
-        "approve": True,
-        "deny": True,
-    }
-
-    def setUp(self):
-        self.parser = argparse.ArgumentParser()
-        add_command_line_options(self.parser)
-
-    @contextlib.contextmanager
-    def assertParseError(self):
-        with self.assertRaises(SystemExit) as e:
-            with self.temporarily_suppress_stderr():
-                yield
-        # Exit code from argparse is guaranteed to be "2".  Reference:
-        # https://docs.python.org/3/library/argparse.html#exiting-methods
-        self.assertEqual(e.exception.code, 2)
-
-    @staticmethod
-    @contextlib.contextmanager
-    def temporarily_suppress_stderr():
-        null = os.open(os.path.devnull, os.O_RDWR)
-        stderrcopy = os.dup(sys.stderr.fileno())
-        os.dup2(null, sys.stderr.fileno())
-        os.close(null)
-        try:
-            yield
-        finally:
-            # restore stderr
-            os.dup2(stderrcopy, sys.stderr.fileno())
-            os.close(stderrcopy)
-
-    def check_option_syntax(self, options):
-        check_option_syntax(self.parser, options)
-
-    def test_actions_requires_client_or_all(self):
-        for action, value in self.actions.items():
-            options = self.parser.parse_args()
-            setattr(options, action, value)
-            with self.assertParseError():
-                self.check_option_syntax(options)
-
-    def test_actions_conflicts_with_verbose(self):
-        for action, value in self.actions.items():
-            options = self.parser.parse_args()
-            setattr(options, action, value)
-            options.verbose = True
-            with self.assertParseError():
-                self.check_option_syntax(options)
-
-    def test_dump_json_conflicts_with_verbose(self):
-        options = self.parser.parse_args()
-        options.dump_json = True
-        options.verbose = True
-        with self.assertParseError():
-            self.check_option_syntax(options)
-
-    def test_dump_json_conflicts_with_action(self):
-        for action, value in self.actions.items():
-            options = self.parser.parse_args()
-            setattr(options, action, value)
-            options.dump_json = True
-            with self.assertParseError():
-                self.check_option_syntax(options)
-
-    def test_all_can_not_be_alone(self):
-        options = self.parser.parse_args()
-        options.all = True
-        with self.assertParseError():
-            self.check_option_syntax(options)
-
-    def test_all_is_ok_with_any_action(self):
-        for action, value in self.actions.items():
-            options = self.parser.parse_args()
-            setattr(options, action, value)
-            options.all = True
-            self.check_option_syntax(options)
-
-    def test_is_enabled_fails_without_client(self):
-        options = self.parser.parse_args()
-        options.is_enabled = True
-        with self.assertParseError():
-            self.check_option_syntax(options)
-
-    def test_is_enabled_works_with_one_client(self):
-        options = self.parser.parse_args()
-        options.is_enabled = True
-        options.client = ["foo"]
-        self.check_option_syntax(options)
-
-    def test_is_enabled_fails_with_two_clients(self):
-        options = self.parser.parse_args()
-        options.is_enabled = True
-        options.client = ["foo", "barbar"]
-        with self.assertParseError():
-            self.check_option_syntax(options)
-
-    def test_remove_can_only_be_combined_with_action_deny(self):
-        for action, value in self.actions.items():
-            if action in {"remove", "deny"}:
-                continue
-            options = self.parser.parse_args()
-            setattr(options, action, value)
-            options.all = True
-            options.remove = True
-            with self.assertParseError():
-                self.check_option_syntax(options)
+        commands = self.commands_from_args(["--disable", "foo"])
+        self.assertEqual(len(commands), 1)
+        command = commands[0]
+        self.assertIsInstance(command, DisableCmd)
+        self.assertEqual(self.options.client, ["foo"])
 
 
 

=== modified file 'mandos-ctl.xml'
--- mandos-ctl.xml	2019-03-08 23:55:34 +0000
+++ mandos-ctl.xml	2019-02-10 04:20:26 +0000
@@ -2,7 +2,7 @@
 <!DOCTYPE refentry PUBLIC "-//OASIS//DTD DocBook XML V4.5//EN"
 	"http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd" [
 <!ENTITY COMMANDNAME "mandos-ctl">
-<!ENTITY TIMESTAMP "2019-03-09">
+<!ENTITY TIMESTAMP "2019-02-10">
 <!ENTITY % common SYSTEM "common.ent">
 %common;
 ]>
@@ -62,22 +62,6 @@
   <refsynopsisdiv>
     <cmdsynopsis>
       <command>&COMMANDNAME;</command>
-      <group>
-	  <arg choice="plain"><option>--verbose</option></arg>
-	  <arg choice="plain"><option>-v</option></arg>
-	  <sbr/>
-	  <arg choice="plain"><option>--dump-json</option></arg>
-	  <arg choice="plain"><option>-j</option></arg>
-      </group>
-      <arg><option>--debug</option></arg>
-      <group>
-	<arg rep='repeat' choice='plain'>
-	  <replaceable>CLIENT</replaceable>
-	</arg>
-      </group>
-    </cmdsynopsis>
-    <cmdsynopsis>
-      <command>&COMMANDNAME;</command>
       <group choice="req">
 	<group>
 	  <arg choice="plain"><option>--enable</option></arg>
@@ -94,10 +78,18 @@
 	<sbr/>
 	<group>
 	  <arg choice="plain"><option>--start-checker</option></arg>
+	</group>
+	<sbr/>
+	<group>
 	  <arg choice="plain"><option>--stop-checker</option></arg>
 	</group>
 	<sbr/>
 	<group>
+	  <arg choice="plain"><option>--remove</option></arg>
+	  <arg choice="plain"><option>-r</option></arg>
+	</group>
+	<sbr/>
+	<group>
 	  <arg choice="plain"><option>--checker
 	  <replaceable>COMMAND</replaceable></option></arg>
 	  <arg choice="plain"><option>-c
@@ -141,6 +133,13 @@
 	</group>
 	<sbr/>
 	<group>
+	  <arg choice="plain"><option>--interval
+	  <replaceable>TIME</replaceable></option></arg>
+	  <arg choice="plain"><option>-i
+	  <replaceable>TIME</replaceable></option></arg>
+	</group>
+	<sbr/>
+	<group>
 	  <arg choice="plain"><option>--host
 	  <replaceable>STRING</replaceable></option></arg>
 	  <arg choice="plain"><option>-H
@@ -163,7 +162,6 @@
 	</group>
       </group>
       <sbr/>
-      <arg><option>--debug</option></arg>
       <group choice="req">
 	<arg choice="plain"><option>--all</option></arg>
 	<arg choice="plain"><option>-a</option></arg>
@@ -175,18 +173,13 @@
     <cmdsynopsis>
       <command>&COMMANDNAME;</command>
       <group>
-	<arg choice="plain"><option>--deny</option></arg>
-	<arg choice="plain"><option>-D</option></arg>
-      </group>
-      <group choice="req">
-	  <arg choice="plain"><option>--remove</option></arg>
-	  <arg choice="plain"><option>-r</option></arg>
-      </group>
-      <sbr/>
-      <arg><option>--debug</option></arg>
-      <group choice="req">
-	<arg choice="plain"><option>--all</option></arg>
-	<arg choice="plain"><option>-a</option></arg>
+	  <arg choice="plain"><option>--verbose</option></arg>
+	  <arg choice="plain"><option>-v</option></arg>
+	  <sbr/>
+	  <arg choice="plain"><option>--dump-json</option></arg>
+	  <arg choice="plain"><option>-j</option></arg>
+      </group>
+      <group>
 	<arg rep='repeat' choice='plain'>
 	  <replaceable>CLIENT</replaceable>
 	</arg>
@@ -198,7 +191,6 @@
 	<arg choice="plain"><option>--is-enabled</option></arg>
 	<arg choice="plain"><option>-V</option></arg>
       </group>
-      <arg><option>--debug</option></arg>
       <arg choice='plain'><replaceable>CLIENT</replaceable></arg>
     </cmdsynopsis>
     <cmdsynopsis>
@@ -512,15 +504,6 @@
       </varlistentry>
       
       <varlistentry>
-	<term><option>--debug</option></term>
-	<listitem>
-	  <para>
-	    Show debug output; currently, this means show D-Bus calls.
-	  </para>
-	</listitem>
-      </varlistentry>
-      
-      <varlistentry>
 	<term><option>--check</option></term>
 	<listitem>
 	  <para>
@@ -598,7 +581,7 @@
       <para>
 
 <!-- do not wrap this line -->
-<userinput>&COMMANDNAME; --timeout="PT5M" --interval="PT1M" foo1.example.org foo2.example.org</userinput>
+<userinput>&COMMANDNAME; --timeout="5m" --interval="1m" foo1.example.org foo2.example.org</userinput>
 
       </para>
     </informalexample>

